==> mingw-w64-python-fastapi-0.103.0-1.src.tar.zst: fastapi-0.103.0/docs/ja/docs/help-fastapi.md <==
# FastAPIを応援 - ヘルプの入手

**FastAPI** は気に入りましたか？

FastAPIやユーザーや開発者を応援したいですか？

もしくは、 **FastAPI** についてヘルプが必要ですか？

とても簡単に応援できます (ただ1、2回クリックするだけのものもあります)。

また、ヘルプを入手する手段がいくつかあります。

## GitHubで **FastAPI** にStar

GitHubでFastAPIに「Star」をつけることができます (右上部のStarボタンをクリック): <a href="https://github.com/tiangolo/fastapi" class="external-link" target="_blank">https://github.com/tiangolo/fastapi</a>. ⭐️

スターを増やすことで、他のユーザーの目につきやすくなり、多くの人にとって便利なものであることを示せます。

## GitHubレポジトリのリリースをWatch

GitHubでFastAPIを「Watch」できます (右上部のWatchボタンをクリック): <a href="https://github.com/tiangolo/fastapi" class="external-link" target="_blank">https://github.com/tiangolo/fastapi</a>. 👀

そこで「Releases only」を選択できます。

これを行うと、**FastAPI** バグ修正や新機能の実装などの新しいリリース (新しいバージョン) があるたびに (メールで) 通知を受け取れます。

## 開発者とつながる

以下で、<a href="https://tiangolo.com" class="external-link" target="_blank">開発者 (Sebastián Ramírez / `tiangolo`)</a> とコンタクトをとれます:

* <a href="https://github.com/tiangolo" class="external-link" target="_blank">**GitHub** でフォロー</a>。
    * 他のオープンソースプロジェクトを確認できます。何かの助けになるものが見つかるかもしれません。
    * 新たなオープンソースプロジェクトを作成したときに通知されます。
* <a href="https://twitter.com/tiangolo" class="external-link" target="_blank">**Twitter** でフォロー</a>。
    * FastAPIの使用用途を教えてください (聞いてみたいです)。
    * 新たなツールの発表やリリースが聞けます。
* <a href="https://www.linkedin.com/in/tiangolo/" class="external-link" target="_blank">**Linkedin** でつながる</a>。
    * 新たなツールの発表やリリースが聞けます (ただしTwitterの方が利用頻度が高いですが 🤷‍♂)。
* <a href="https://dev.to/tiangolo" class="external-link" target="_blank">**Dev.to**</a> や <a href="https://medium.com/@tiangolo" class="external-link" target="_blank">**Medium**</a> で著作物を読む (またはフォロー)。
    * アイデアや作成ツールについての記事が読めます。
    * 新規記事の執筆を通知してくれます。

## **FastAPI** に関するツイート

<a href="https://twitter.com/compose/tweet?text=I'm loving FastAPI because... https://github.com/tiangolo/fastapi cc @tiangolo" class="external-link" target="_blank">**FastAPI** についてツイート</a>し、開発者や他の人にどこが気に入ったのか教えてください。🎉

**FastAPI** がどのように使われ、どこが気に入られ、どんなプロジェクト/会社で使われているかなどについて知りたいです。

## FastAPIに投票

* <a href="https://www.slant.co/options/34241/~fastapi-review" class="external-link" target="_blank">Slantで **FastAPI** に投票</a>
* <a href="https://alternativeto.net/software/fastapi/" class="external-link" target="_blank">AlternativeToで **FastAPI** に投票</a>
* <a href="https://github.com/marmelab/awesome-rest/pull/93" class="external-link" target="_blank">awesome-restで **FastAPI** に投票</a>

## GitHub issuesで他の人を助ける

<a href="https://github.com/tiangolo/fastapi/issues" class="external-link" target="_blank">既存のissues</a>を確認して、他の人を助けてみてください。皆さんが回答を知っているかもしれない質問がほとんどです。🤓

## GitHubレポジトリをWatch

GitHubでFastAPIを「watch」できます (右上部の「watch」ボタンをクリック): <a href="https://github.com/tiangolo/fastapi" class="external-link" target="_blank">https://github.com/tiangolo/fastapi</a>. 👀

「Releases only」ではなく「Watching」を選択すると、新たなissueが立てられた際に通知されます。

そして、issueを解決し他の人を助けることができます。

## issuesを立てる

GitHubレポジトリで<a href="https://github.com/tiangolo/fastapi/issues/new/choose" class="external-link" target="_blank">新たなissueを立てられます</a>。例えば:

* 質問、または、問題の報告
* 新機能の提案

**Note**: issueを立てた人は、他の人の手助けもお願いします。😉

## プルリクエストをする

以下の様な<a href="https://github.com/tiangolo/fastapi" class="external-link" target="_blank">プルリクエストを作成</a>できます:

* ドキュメントのタイプミスを修正。
* 新たなドキュメントセクションを提案。
* 既存のissue/バグを修正。
* 新機能を追加。

## チャットに参加

Gitterでチャットに参加: <a href="https://gitter.im/tiangolo/fastapi" class="external-link" target="_blank">https://gitter.im/tiangolo/fastapi</a>.

そこで、他の人と手早く会話したり、手助けやアイデアの共有などができます。

しかし、「自由な会話」が許容されているので一般的すぎて回答が難しい質問もしやすくなります。そのせいで回答を得られないかもしれません。

GitHub issuesでは良い回答を得やすい質問ができるように、もしくは、質問する前に自身で解決できるようにテンプレートがガイドしてくれます。そして、GitHubではたとえ時間がかかっても全てに答えているか確認できます。個人的にはGitterチャットでは同じことはできないです。😅

Gitterでの会話はGitHubほど簡単に検索できないので、質問と回答が会話の中に埋もれてしまいます。

一方、チャットには1000人以上いるので、いつでも話し相手が見つかる可能性が高いです。😄

## 開発者のスポンサーになる

<a href="https://github.com/sponsors/tiangolo" class="external-link" target="_blank">GitHub sponsors</a>を通して開発者を経済的にサポートできます。

そこで、感謝の気持ちを伝えるためにコーヒー☕️を買うことができます 😄。

## FastAPIを強化するツールのスポンサーになる

ドキュメントで見たように、FastAPIはStarletteとPydanticという巨人の肩に乗っています。

以下のスポンサーになることもできます:

* <a href="https://github.com/sponsors/samuelcolvin" class="external-link" target="_blank">Samuel Colvin (Pydantic)</a>
* <a href="https://github.com/sponsors/encode" class="external-link" target="_blank">Encode (Starlette, Uvicorn)</a>

---

Thanks! 🚀

==> mingw-w64-python-fastapi-0.114.2-1.src.tar.zst: fastapi-0.114.2/docs/ja/docs/help-fastapi.md <==
# FastAPIを応援 - ヘルプの入手

**FastAPI** は気に入りましたか？

FastAPIやユーザーや開発者を応援したいですか？

もしくは、 **FastAPI** についてヘルプが必要ですか？

とても簡単に応援できます (ただ1、2回クリックするだけのものもあります)。

また、ヘルプを入手する手段がいくつかあります。

## GitHubで **FastAPI** にStar

GitHubでFastAPIに「Star」をつけることができます (右上部のStarボタンをクリック): <a href="https://github.com/fastapi/fastapi" class="external-link" target="_blank">https://github.com/fastapi/fastapi</a>. ⭐️

スターを増やすことで、他のユーザーの目につきやすくなり、多くの人にとって便利なものであることを示せます。

## GitHubレポジトリのリリースをWatch

GitHubでFastAPIを「Watch」できます (右上部のWatchボタンをクリック): <a href="https://github.com/fastapi/fastapi" class="external-link" target="_blank">https://github.com/fastapi/fastapi</a>. 👀

そこで「Releases only」を選択できます。

これを行うと、**FastAPI** バグ修正や新機能の実装などの新しいリリース (新しいバージョン) があるたびに (メールで) 通知を受け取れます。

## 開発者とつながる

以下で、<a href="https://tiangolo.com" class="external-link" target="_blank">開発者 (Sebastián Ramírez / `tiangolo`)</a> とコンタクトをとれます:

* <a href="https://github.com/tiangolo" class="external-link" target="_blank">**GitHub** でフォロー</a>。
    * 他のオープンソースプロジェクトを確認できます。何かの助けになるものが見つかるかもしれません。
    * 新たなオープンソースプロジェクトを作成したときに通知されます。
* <a href="https://twitter.com/tiangolo" class="external-link" target="_blank">**Twitter** でフォロー</a>。
    * FastAPIの使用用途を教えてください (聞いてみたいです)。
    * 新たなツールの発表やリリースが聞けます。
* <a href="https://www.linkedin.com/in/tiangolo/" class="external-link" target="_blank">**Linkedin** でつながる</a>。
    * 新たなツールの発表やリリースが聞けます (ただしTwitterの方が利用頻度が高いですが 🤷‍♂)。
* <a href="https://dev.to/tiangolo" class="external-link" target="_blank">**Dev.to**</a> や <a href="https://medium.com/@tiangolo" class="external-link" target="_blank">**Medium**</a> で著作物を読む (またはフォロー)。
    * アイデアや作成ツールについての記事が読めます。
    * 新規記事の執筆を通知してくれます。

## **FastAPI** に関するツイート

<a href="https://twitter.com/compose/tweet?text=I'm loving FastAPI because... https://github.com/fastapi/fastapi cc @tiangolo" class="external-link" target="_blank">**FastAPI** についてツイート</a>し、開発者や他の人にどこが気に入ったのか教えてください。🎉

**FastAPI** がどのように使われ、どこが気に入られ、どんなプロジェクト/会社で使われているかなどについて知りたいです。

## FastAPIに投票

* <a href="https://www.slant.co/options/34241/~fastapi-review" class="external-link" target="_blank">Slantで **FastAPI** に投票</a>
* <a href="https://alternativeto.net/software/fastapi/" class="external-link" target="_blank">AlternativeToで **FastAPI** に投票</a>
* <a href="https://github.com/marmelab/awesome-rest/pull/93" class="external-link" target="_blank">awesome-restで **FastAPI** に投票</a>

## GitHub issuesで他の人を助ける

<a href="https://github.com/fastapi/fastapi/issues" class="external-link" target="_blank">既存のissues</a>を確認して、他の人を助けてみてください。皆さんが回答を知っているかもしれない質問がほとんどです。🤓

## GitHubレポジトリをWatch

GitHubでFastAPIを「watch」できます (右上部の「watch」ボタンをクリック): <a href="https://github.com/fastapi/fastapi" class="external-link" target="_blank">https://github.com/fastapi/fastapi</a>. 👀

「Releases only」ではなく「Watching」を選択すると、新たなissueが立てられた際に通知されます。

そして、issueを解決し他の人を助けることができます。

## issuesを立てる

GitHubレポジトリで<a href="https://github.com/fastapi/fastapi/issues/new/choose" class="external-link" target="_blank">新たなissueを立てられます</a>。例えば:

* 質問、または、問題の報告
* 新機能の提案

**Note**: issueを立てた人は、他の人の手助けもお願いします。😉

## プルリクエストをする

以下の様な<a href="https://github.com/fastapi/fastapi" class="external-link" target="_blank">プルリクエストを作成</a>できます:

* ドキュメントのタイプミスを修正。
* 新たなドキュメントセクションを提案。
* 既存のissue/バグを修正。
* 新機能を追加。

## 開発者のスポンサーになる

<a href="https://github.com/sponsors/tiangolo" class="external-link" target="_blank">GitHub sponsors</a>を通して開発者を経済的にサポートできます。

そこで、感謝の気持ちを伝えるためにコーヒー☕️を買うことができます 😄。

## FastAPIを強化するツールのスポンサーになる

ドキュメントで見たように、FastAPIはStarletteとPydanticという巨人の肩に乗っています。

以下のスポンサーになることもできます:

* <a href="https://github.com/sponsors/samuelcolvin" class="external-link" target="_blank">Samuel Colvin (Pydantic)</a>
* <a href="https://github.com/sponsors/encode" class="external-link" target="_blank">Encode (Starlette, Uvicorn)</a>

---

Thanks! 🚀
